# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dnaerys.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dnaerys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rdnaerys.proto\x12\x18org.dnaerys.cluster.grpc\"\x0f\n\rHealthRequest\" \n\x0eHealthResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x15\n\x13\x43lusterNodesRequest\"m\n\x14\x43lusterNodesResponse\x12\x14\n\x0c\x61\x63tive_nodes\x18\x01 \x03(\t\x12\x16\n\x0einactive_nodes\x18\x02 \x03(\t\x12\x13\n\x0btotal_nodes\x18\x03 \x01(\x05\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\"2\n\x12\x44\x61tasetInfoRequest\x12\x1c\n\x14return_samples_names\x18\x01 \x01(\x08\"\x86\x03\n\x13\x44\x61tasetInfoResponse\x12\x31\n\x07\x63ohorts\x18\x01 \x03(\x0b\x32 .org.dnaerys.cluster.grpc.Cohort\x12\x15\n\rsamples_total\x18\x02 \x01(\x05\x12\x15\n\rfemales_total\x18\x03 \x01(\x05\x12\x13\n\x0bmales_total\x18\x04 \x01(\x05\x12\x16\n\x0evariants_total\x18\x05 \x01(\x05\x12\x37\n\x08\x61ssembly\x18\x06 \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x0b\n\x03rto\x18\x07 \x01(\x08\x12*\n\x03prs\x18\x08 \x03(\x0b\x32\x1d.org.dnaerys.cluster.grpc.PRS\x12\x11\n\ttimestamp\x18\t \x01(\t\x12\x13\n\x0b\x64\x61ta_format\x18\n \x01(\x05\x12\r\n\x05notes\x18\x0b \x01(\t\x12\x13\n\x0brings_total\x18\x0c \x01(\x05\x12\x12\n\nelapsed_ms\x18\x0e \x01(\x03\x12\x0f\n\x07node_id\x18\x0f \x01(\t\"\xab\x01\n\x06\x43ohort\x12\x13\n\x0b\x63ohort_name\x18\x01 \x01(\t\x12\x15\n\rsamples_count\x18\x02 \x01(\x05\x12\x14\n\x0c\x66\x65male_count\x18\x03 \x01(\x05\x12\x12\n\nmale_count\x18\x04 \x01(\x05\x12\x1c\n\x14\x66\x65male_samples_names\x18\x05 \x03(\t\x12\x1a\n\x12male_samples_names\x18\x06 \x03(\t\x12\x11\n\tsynthetic\x18\x07 \x01(\x08\"6\n\x03PRS\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61rdinality\x18\x03 \x01(\x05\"\xfb\x06\n\x0b\x41nnotations\x12;\n\x0cvariant_type\x18\x01 \x03(\x0e\x32%.org.dnaerys.cluster.grpc.VariantType\x12;\n\x0c\x66\x65\x61ture_type\x18\x02 \x03(\x0e\x32%.org.dnaerys.cluster.grpc.FeatureType\x12\x33\n\x08\x62io_type\x18\x03 \x03(\x0e\x32!.org.dnaerys.cluster.grpc.BioType\x12:\n\x0b\x63onsequence\x18\x04 \x03(\x0e\x32%.org.dnaerys.cluster.grpc.Consequence\x12\x30\n\x06impact\x18\x05 \x03(\x0e\x32 .org.dnaerys.cluster.grpc.Impact\x12;\n\x07\x63linsgn\x18\x06 \x03(\x0e\x32*.org.dnaerys.cluster.grpc.ClinSignificance\x12\r\n\x05\x61\x66_lt\x18\x07 \x01(\x02\x12\r\n\x05\x61\x66_gt\x18\x08 \x01(\x02\x12\x1b\n\x13gnomad_exomes_af_lt\x18\t \x01(\x02\x12\x1b\n\x13gnomad_exomes_af_gt\x18\n \x01(\x02\x12\x1c\n\x14gnomad_genomes_af_lt\x18\x0b \x01(\x02\x12\x1c\n\x14gnomad_genomes_af_gt\x18\x0c \x01(\x02\x12,\n\x04sift\x18\r \x03(\x0e\x32\x1e.org.dnaerys.cluster.grpc.SIFT\x12\x34\n\x08polyphen\x18\x0e \x03(\x0e\x32\".org.dnaerys.cluster.grpc.PolyPhen\x12\x13\n\x0b\x63\x61\x64\x64_raw_lt\x18\x0f \x01(\x02\x12\x13\n\x0b\x63\x61\x64\x64_raw_gt\x18\x10 \x01(\x02\x12\x15\n\rcadd_phred_lt\x18\x11 \x01(\x02\x12\x15\n\rcadd_phred_gt\x18\x12 \x01(\x02\x12\x13\n\x0b\x61m_score_lt\x18\x13 \x01(\x02\x12\x13\n\x0b\x61m_score_gt\x18\x14 \x01(\x02\x12\x39\n\x08\x61m_class\x18\x15 \x03(\x0e\x32\'.org.dnaerys.cluster.grpc.AlphaMissense\x12\x15\n\rbiallelicOnly\x18\x16 \x01(\x08\x12\x18\n\x10multiallelicOnly\x18\x17 \x01(\x08\x12\x14\n\x0c\x65xcludeMales\x18\x18 \x01(\x08\x12\x16\n\x0e\x65xcludeFemales\x18\x19 \x01(\x08\"\xd9\x02\n\x16\x41llelesInRegionRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\x12\x0c\n\x04skip\x18\x0c \x01(\x05\x12\r\n\x05limit\x18\r \x01(\x05\"\x86\x03\n\x17\x41llelesInBracketRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\x11\n\tstart_min\x18\x02 \x01(\x05\x12\x11\n\tstart_max\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_min\x18\x04 \x01(\x05\x12\x0f\n\x07\x65nd_max\x18\x05 \x01(\x05\x12\x0b\n\x03ref\x18\x06 \x01(\t\x12\x0b\n\x03\x61lt\x18\x07 \x01(\t\x12\x0b\n\x03hom\x18\x08 \x01(\x08\x12\x0b\n\x03het\x18\t \x01(\x08\x12\x32\n\x03\x61nn\x18\n \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\x0b \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0c \x01(\x05\x12\x18\n\x10variantMaxLength\x18\r \x01(\x05\x12\x0c\n\x04skip\x18\x0e \x01(\x05\x12\r\n\x05limit\x18\x0f \x01(\x05\"\xa0\x03\n AllelesInBracketInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\x11\n\tstart_min\x18\x02 \x01(\x05\x12\x11\n\tstart_max\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_min\x18\x04 \x01(\x05\x12\x0f\n\x07\x65nd_max\x18\x05 \x01(\x05\x12\x0b\n\x03ref\x18\x06 \x01(\t\x12\x0b\n\x03\x61lt\x18\x07 \x01(\t\x12\x0b\n\x03hom\x18\x08 \x01(\x08\x12\x0b\n\x03het\x18\t \x01(\x08\x12\x32\n\x03\x61nn\x18\n \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\x0b \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0c \x01(\x05\x12\x18\n\x10variantMaxLength\x18\r \x01(\x05\x12\x0f\n\x07samples\x18\x0e \x03(\t\x12\x0c\n\x04skip\x18\x0f \x01(\x05\x12\r\n\x05limit\x18\x10 \x01(\x05\"\xf3\x02\n\x1f\x41llelesInRegionInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x0f\n\x07samples\x18\n \x03(\t\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"\xdf\x02\n\x1c\x41llelesInMultiRegionsRequest\x12\x31\n\x03\x63hr\x18\x01 \x03(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x03(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x03(\x05\x12\x0b\n\x03ref\x18\x04 \x03(\t\x12\x0b\n\x03\x61lt\x18\x05 \x03(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\x12\x0c\n\x04skip\x18\x0c \x01(\x05\x12\r\n\x05limit\x18\r \x01(\x05\"\xf9\x02\n%AllelesInMultiRegionsInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x03(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x03(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x03(\x05\x12\x0b\n\x03ref\x18\x04 \x03(\t\x12\x0b\n\x03\x61lt\x18\x05 \x03(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x0f\n\x07samples\x18\n \x03(\t\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"\xb0\x01\n\x0f\x41llelesResponse\x12\x33\n\x08variants\x18\x01 \x03(\x0b\x32!.org.dnaerys.cluster.grpc.Variant\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x10\n\x08\x61\x66\x66\x65\x63ted\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\xef\x02\n\x07Variant\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\n\n\x02\x61\x66\x18\x06 \x01(\x02\x12\n\n\x02\x61\x63\x18\x07 \x01(\x02\x12\n\n\x02\x61n\x18\x08 \x01(\x05\x12\x0c\n\x04homc\x18\t \x01(\x05\x12\x0c\n\x04hetc\x18\n \x01(\x05\x12\x0c\n\x04misc\x18\x0b \x01(\x05\x12\r\n\x05homfc\x18\x0c \x01(\x05\x12\r\n\x05hetfc\x18\r \x01(\x05\x12\r\n\x05misfc\x18\x0e \x01(\x05\x12\x0f\n\x07gnomADe\x18\x0f \x01(\x02\x12\x0f\n\x07gnomADg\x18\x10 \x01(\x02\x12\x10\n\x08\x63\x61\x64\x64_raw\x18\x11 \x01(\x02\x12\x12\n\ncadd_phred\x18\x12 \x01(\x02\x12\x10\n\x08\x61m_score\x18\x13 \x01(\x02\x12\x13\n\x0b\x61mino_acids\x18\x14 \x01(\t\x12\x11\n\tbiallelic\x18\x15 \x01(\x08\"\xc2\x01\n\x18\x41llelesWithStatsResponse\x12<\n\x08variants\x18\x01 \x03(\x0b\x32*.org.dnaerys.cluster.grpc.VariantWithStats\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x10\n\x08\x61\x66\x66\x65\x63ted\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\xe1\x01\n\x10VariantWithStats\x12\x32\n\x07variant\x18\x01 \x01(\x0b\x32!.org.dnaerys.cluster.grpc.Variant\x12\x0b\n\x03vaf\x18\x02 \x01(\x02\x12\x0b\n\x03vac\x18\x03 \x01(\x02\x12\x0b\n\x03van\x18\x04 \x01(\x05\x12\r\n\x05vhomc\x18\x05 \x01(\x05\x12\r\n\x05vhetc\x18\x06 \x01(\x05\x12\x0e\n\x06vhomfc\x18\x07 \x01(\x05\x12\x0e\n\x06vhetfc\x18\x08 \x01(\x05\x12\x0c\n\x04phwe\x18\t \x01(\x02\x12\r\n\x05pchi2\x18\n \x01(\x02\x12\n\n\x02or\x18\x0b \x01(\x02\x12\x0b\n\x03ibc\x18\x0c \x01(\x02\":\n\x0fTopNchi2Request\x12\t\n\x01n\x18\x01 \x01(\x05\x12\x0f\n\x07samples\x18\x02 \x03(\t\x12\x0b\n\x03seq\x18\x03 \x01(\x08\"(\n\x0eTopNHWERequest\x12\t\n\x01n\x18\x01 \x01(\x05\x12\x0b\n\x03seq\x18\x02 \x01(\x08\"\xd9\x02\n\x16SamplesInRegionRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"\xdf\x02\n\x1cSamplesInMultiRegionsRequest\x12\x31\n\x03\x63hr\x18\x01 \x03(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x03(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x03(\x05\x12\x0b\n\x03ref\x18\x04 \x03(\t\x12\x0b\n\x03\x61lt\x18\x05 \x03(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\x12\x0c\n\x04skip\x18\x0c \x01(\x05\x12\r\n\x05limit\x18\r \x01(\x05\"\xb1\x01\n\x14SamplesHomRefRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\x10\n\x08position\x18\x02 \x01(\x05\x12\x37\n\x08\x61ssembly\x18\x03 \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x0c\n\x04skip\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\"\x8c\x01\n\x0fSamplesResponse\x12\x0f\n\x07samples\x18\x01 \x03(\t\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x10\n\x08\x61\x66\x66\x65\x63ted\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\xe9\x02\n\rDeNovoRequest\x12\x0f\n\x07parent1\x18\x01 \x01(\t\x12\x0f\n\x07parent2\x18\x02 \x01(\t\x12\x0f\n\x07proband\x18\x03 \x01(\t\x12\x31\n\x03\x63hr\x18\x04 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x05 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x06 \x01(\x05\x12\x0b\n\x03ref\x18\x07 \x01(\t\x12\x0b\n\x03\x61lt\x18\x08 \x01(\t\x12\x32\n\x03\x61nn\x18\t \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\n \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"\x87\x03\n\x12HetDominantRequest\x12\x17\n\x0f\x61\x66\x66\x65\x63ted_parent\x18\x01 \x01(\t\x12\x19\n\x11unaffected_parent\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x66\x66\x65\x63ted_child\x18\x03 \x01(\t\x12\x31\n\x03\x63hr\x18\x04 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x05 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x06 \x01(\x05\x12\x0b\n\x03ref\x18\x07 \x01(\t\x12\x0b\n\x03\x61lt\x18\x08 \x01(\t\x12\x32\n\x03\x61nn\x18\t \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\n \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"\x8c\x03\n\x13HomRecessiveRequest\x12\x1a\n\x12unaffected_parent1\x18\x01 \x01(\t\x12\x1a\n\x12unaffected_parent2\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x66\x66\x65\x63ted_child\x18\x03 \x01(\t\x12\x31\n\x03\x63hr\x18\x04 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x05 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x06 \x01(\x05\x12\x0b\n\x03ref\x18\x07 \x01(\t\x12\x0b\n\x03\x61lt\x18\x08 \x01(\t\x12\x32\n\x03\x61nn\x18\t \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\n \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0b \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0c \x01(\x05\x12\x0c\n\x04skip\x18\r \x01(\x05\x12\r\n\x05limit\x18\x0e \x01(\x05\"i\n\nPRSRequest\x12\x10\n\x08prs_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ohort_name\x18\x02 \x01(\t\x12\x0f\n\x07samples\x18\x03 \x03(\t\x12\x10\n\x08\x64ominant\x18\x04 \x01(\x08\x12\x11\n\trecessive\x18\x05 \x01(\x08\"\xf3\x01\n\x0bPRSResponse\x12\x10\n\x08prs_name\x18\x01 \x01(\t\x12<\n\rsample_scores\x18\x02 \x03(\x0b\x32%.org.dnaerys.cluster.grpc.SampleScore\x12\x10\n\x08\x64ominant\x18\x03 \x01(\x08\x12\x11\n\trecessive\x18\x04 \x01(\x08\x12\x17\n\x0fprs_cardinality\x18\x05 \x01(\x05\x12\x1a\n\x12incomplete_cluster\x18\x06 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x07 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x08 \x01(\x03\x12\x0f\n\x07node_id\x18\t \x01(\t\"\x94\x01\n\x0bSampleScore\x12\x0e\n\x06sample\x18\x01 \x01(\t\x12\x12\n\nscores_sum\x18\x02 \x01(\x02\x12\x1a\n\x12hethom_cardinality\x18\x03 \x01(\x05\x12\x17\n\x0fref_cardinality\x18\x04 \x01(\x05\x12\x17\n\x0fmis_cardinality\x18\x05 \x01(\x05\x12\x13\n\x0bimputed_sum\x18\x06 \x01(\x02\"\xa0\x01\n\rFstatXRequest\x12\x13\n\x0b\x63ohort_name\x18\x01 \x01(\t\x12\x0f\n\x07samples\x18\x02 \x03(\t\x12\x15\n\raaf_threshold\x18\x03 \x01(\x02\x12\x18\n\x10\x66\x65male_threshold\x18\x04 \x01(\x02\x12\x16\n\x0emale_threshold\x18\x05 \x01(\x02\x12\x13\n\x0binclude_par\x18\x06 \x01(\x08\x12\x0b\n\x03seq\x18\x07 \x01(\x08\"\xeb\x01\n\x13SexMismatchResponse\x12<\n\x0emismatch_males\x18\x01 \x03(\x0b\x32$.org.dnaerys.cluster.grpc.SampleStat\x12>\n\x10mismatch_females\x18\x02 \x03(\x0b\x32$.org.dnaerys.cluster.grpc.SampleStat\x12\x1a\n\x12incomplete_cluster\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"X\n\nSampleStat\x12\x0e\n\x06sample\x18\x01 \x01(\t\x12\x14\n\x0creported_sex\x18\x02 \x01(\t\x12\x14\n\x0cobserved_sex\x18\x03 \x01(\t\x12\x0e\n\x06\x66_stat\x18\x04 \x01(\x02\"\xd4\x01\n\x0e\x46statXResponse\x12\x33\n\x05males\x18\x01 \x03(\x0b\x32$.org.dnaerys.cluster.grpc.SampleStat\x12\x35\n\x07\x66\x65males\x18\x02 \x03(\x0b\x32$.org.dnaerys.cluster.grpc.SampleStat\x12\x1a\n\x12incomplete_cluster\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\x8f\x01\n\x0eKinshipRequest\x12\x13\n\x0b\x63ohort_name\x18\x01 \x01(\t\x12\x0f\n\x07samples\x18\x02 \x03(\t\x12\x37\n\x06\x64\x65gree\x18\x03 \x01(\x0e\x32\'.org.dnaerys.cluster.grpc.KinshipDegree\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12\x0b\n\x03seq\x18\x05 \x01(\x08\"B\n\x11KinshipDuoRequest\x12\x0f\n\x07sample1\x18\x01 \x01(\t\x12\x0f\n\x07sample2\x18\x02 \x01(\t\x12\x0b\n\x03seq\x18\x03 \x01(\x08\"\xa0\x01\n\x12KinshipTrioRequest\x12\x0f\n\x07sample1\x18\x01 \x01(\t\x12\x0f\n\x07sample2\x18\x02 \x01(\t\x12\x0f\n\x07sample3\x18\x03 \x01(\t\x12\x37\n\x06\x64\x65gree\x18\x04 \x01(\x0e\x32\'.org.dnaerys.cluster.grpc.KinshipDegree\x12\x11\n\tthreshold\x18\x05 \x01(\x02\x12\x0b\n\x03seq\x18\x06 \x01(\x08\"\x9d\x01\n\x0fKinshipResponse\x12\x32\n\x03rel\x18\x01 \x03(\x0b\x32%.org.dnaerys.cluster.grpc.Relatedness\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x03 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x04 \x01(\x03\x12\x0f\n\x07node_id\x18\x05 \x01(\t\"y\n\x0bRelatedness\x12\x0f\n\x07sample1\x18\x01 \x01(\t\x12\x0f\n\x07sample2\x18\x02 \x01(\t\x12\x37\n\x06\x64\x65gree\x18\x03 \x01(\x0e\x32\'.org.dnaerys.cluster.grpc.KinshipDegree\x12\x0f\n\x07phi_bwf\x18\x04 \x01(\x02\"\x98\x01\n\x14SampleKinshipRequest\x12\x12\n\nsample_vcf\x18\x01 \x01(\t\x12\x13\n\x0b\x63ohort_name\x18\x02 \x01(\t\x12\x37\n\x06\x64\x65gree\x18\x03 \x01(\x0e\x32\'.org.dnaerys.cluster.grpc.KinshipDegree\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12\x0b\n\x03seq\x18\x05 \x01(\x08\"\xc3\x01\n\x15SampleKinshipResponse\x12;\n\x03rel\x18\x01 \x03(\x0b\x32..org.dnaerys.cluster.grpc.RelatednessPerSample\x12\x15\n\raccepted_snvs\x18\x02 \x01(\x05\x12\x1a\n\x12incomplete_cluster\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\xc7\x01\n\x14RelatednessPerSample\x12\x0e\n\x06sample\x18\x01 \x01(\t\x12\x37\n\x06\x64\x65gree\x18\x02 \x01(\x0e\x32\'.org.dnaerys.cluster.grpc.KinshipDegree\x12\x0f\n\x07phi_bwf\x18\x03 \x01(\x02\x12\x13\n\x0b\x63ommon_loci\x18\x04 \x01(\x05\x12\x0e\n\x06nHetS1\x18\x05 \x01(\x05\x12\x0e\n\x06nHetS2\x18\x06 \x01(\x05\x12\x10\n\x08nHetS1S2\x18\x07 \x01(\x05\x12\x0e\n\x06nHomOp\x18\x08 \x01(\x05\"\xc1\x02\n\x1b\x43ountAllelesInRegionRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\"\xdb\x02\n$CountAllelesInRegionInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0b\n\x03ref\x18\x04 \x01(\t\x12\x0b\n\x03\x61lt\x18\x05 \x01(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\x12\x0f\n\x07samples\x18\x0c \x03(\t\"\xee\x02\n\x1c\x43ountAllelesInBracketRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\x11\n\tstart_min\x18\x02 \x01(\x05\x12\x11\n\tstart_max\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_min\x18\x04 \x01(\x05\x12\x0f\n\x07\x65nd_max\x18\x05 \x01(\x05\x12\x0b\n\x03ref\x18\x06 \x01(\t\x12\x0b\n\x03\x61lt\x18\x07 \x01(\t\x12\x0b\n\x03hom\x18\x08 \x01(\x08\x12\x0b\n\x03het\x18\t \x01(\x08\x12\x32\n\x03\x61nn\x18\n \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\x0b \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0c \x01(\x05\x12\x18\n\x10variantMaxLength\x18\r \x01(\x05\"\x88\x03\n%CountAllelesInBracketInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x01(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\x11\n\tstart_min\x18\x02 \x01(\x05\x12\x11\n\tstart_max\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_min\x18\x04 \x01(\x05\x12\x0f\n\x07\x65nd_max\x18\x05 \x01(\x05\x12\x0b\n\x03ref\x18\x06 \x01(\t\x12\x0b\n\x03\x61lt\x18\x07 \x01(\t\x12\x0b\n\x03hom\x18\x08 \x01(\x08\x12\x0b\n\x03het\x18\t \x01(\x08\x12\x32\n\x03\x61nn\x18\n \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\x0b \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\x0c \x01(\x05\x12\x18\n\x10variantMaxLength\x18\r \x01(\x05\x12\x0f\n\x07samples\x18\x0e \x03(\t\"\xc7\x02\n!CountAllelesInMultiRegionsRequest\x12\x31\n\x03\x63hr\x18\x01 \x03(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x03(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x03(\x05\x12\x0b\n\x03ref\x18\x04 \x03(\t\x12\x0b\n\x03\x61lt\x18\x05 \x03(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\"\xe1\x02\n*CountAllelesInMultiRegionsInSamplesRequest\x12\x31\n\x03\x63hr\x18\x01 \x03(\x0e\x32$.org.dnaerys.cluster.grpc.Chromosome\x12\r\n\x05start\x18\x02 \x03(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x03(\x05\x12\x0b\n\x03ref\x18\x04 \x03(\t\x12\x0b\n\x03\x61lt\x18\x05 \x03(\t\x12\x0b\n\x03hom\x18\x06 \x01(\x08\x12\x0b\n\x03het\x18\x07 \x01(\x08\x12\x32\n\x03\x61nn\x18\x08 \x01(\x0b\x32%.org.dnaerys.cluster.grpc.Annotations\x12\x37\n\x08\x61ssembly\x18\t \x01(\x0e\x32%.org.dnaerys.cluster.grpc.RefAssembly\x12\x18\n\x10variantMinLength\x18\n \x01(\x05\x12\x18\n\x10variantMaxLength\x18\x0b \x01(\x05\x12\x0f\n\x07samples\x18\x0c \x03(\t\"\x8f\x01\n\x14\x43ountAllelesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x10\n\x08\x61\x66\x66\x65\x63ted\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t\"\x8f\x01\n\x14\x43ountSamplesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x1a\n\x12incomplete_cluster\x18\x02 \x01(\x08\x12\x10\n\x08\x61\x66\x66\x65\x63ted\x18\x03 \x01(\x08\x12\x12\n\nelapsed_ms\x18\x04 \x01(\x03\x12\x15\n\relapsed_db_ms\x18\x05 \x01(\x03\x12\x0f\n\x07node_id\x18\x06 \x01(\t*?\n\x0bRefAssembly\x12\x18\n\x14\x41SSEMBLY_UNSPECIFIED\x10\x00\x12\n\n\x06GRCh37\x10\x01\x12\n\n\x06GRCh38\x10\x02*\xc9\x02\n\nChromosome\x12\x1a\n\x16\x43HROMOSOME_UNSPECIFIED\x10\x00\x12\t\n\x05\x43HR_1\x10\x01\x12\t\n\x05\x43HR_2\x10\x02\x12\t\n\x05\x43HR_3\x10\x03\x12\t\n\x05\x43HR_4\x10\x04\x12\t\n\x05\x43HR_5\x10\x05\x12\t\n\x05\x43HR_6\x10\x06\x12\t\n\x05\x43HR_7\x10\x07\x12\t\n\x05\x43HR_8\x10\x08\x12\t\n\x05\x43HR_9\x10\t\x12\n\n\x06\x43HR_10\x10\n\x12\n\n\x06\x43HR_11\x10\x0b\x12\n\n\x06\x43HR_12\x10\x0c\x12\n\n\x06\x43HR_13\x10\r\x12\n\n\x06\x43HR_14\x10\x0e\x12\n\n\x06\x43HR_15\x10\x0f\x12\n\n\x06\x43HR_16\x10\x10\x12\n\n\x06\x43HR_17\x10\x11\x12\n\n\x06\x43HR_18\x10\x12\x12\n\n\x06\x43HR_19\x10\x13\x12\n\n\x06\x43HR_20\x10\x14\x12\n\n\x06\x43HR_21\x10\x15\x12\n\n\x06\x43HR_22\x10\x16\x12\t\n\x05\x43HR_X\x10\x17\x12\t\n\x05\x43HR_Y\x10\x18\x12\n\n\x06\x43HR_MT\x10\x19*\xc3\x06\n\x0bVariantType\x12\x1b\n\x17VARIANTTYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03SNV\x10\x01\x12\r\n\tINSERTION\x10\x02\x12\x0c\n\x08\x44\x45LETION\x10\x03\x12\t\n\x05INDEL\x10\x04\x12\x10\n\x0cSUBSTITUTION\x10\x05\x12\r\n\tINVERSION\x10\x06\x12\x11\n\rTRANSLOCATION\x10\x07\x12\x0f\n\x0b\x44UPLICATION\x10\x08\x12\x11\n\rALU_INSERTION\x10\t\x12!\n\x1d\x43OMPLEX_STRUCTURAL_ALTERATION\x10\n\x12\x18\n\x14\x43OMPLEX_SUBSTITUTION\x10\x0b\x12\x14\n\x10\x43OPY_NUMBER_GAIN\x10\x0c\x12\x14\n\x10\x43OPY_NUMBER_LOSS\x10\r\x12\x19\n\x15\x43OPY_NUMBER_VARIATION\x10\x0e\x12\x1f\n\x1bINTERCHROMOSOMAL_BREAKPOINT\x10\x0f\x12\"\n\x1eINTERCHROMOSOMAL_TRANSLOCATION\x10\x10\x12\x1f\n\x1bINTRACHROMOSOMAL_BREAKPOINT\x10\x11\x12\"\n\x1eINTRACHROMOSOMAL_TRANSLOCATION\x10\x12\x12\x1a\n\x16LOSS_OF_HETEROZYGOSITY\x10\x13\x12\x1b\n\x17MOBILE_ELEMENT_DELETION\x10\x14\x12\x1c\n\x18MOBILE_ELEMENT_INSERTION\x10\x15\x12\x1c\n\x18NOVEL_SEQUENCE_INSERTION\x10\x16\x12!\n\x1dSHORT_TANDEM_REPEAT_VARIATION\x10\x17\x12\x16\n\x12TANDEM_DUPLICATION\x10\x18\x12\t\n\x05PROBE\x10\x19\x12\x10\n\x0c\x41LU_DELETION\x10\x1a\x12\x11\n\rHERV_DELETION\x10\x1b\x12\x12\n\x0eHERV_INSERTION\x10\x1c\x12\x12\n\x0eLINE1_DELETION\x10\x1d\x12\x13\n\x0fLINE1_INSERTION\x10\x1e\x12\x10\n\x0cSVA_DELETION\x10\x1f\x12\x11\n\rSVA_INSERTION\x10 \x12%\n!COMPLEX_CHROMOSOMAL_REARRANGEMENT\x10!\x12\x17\n\x13SEQUENCE_ALTERATION\x10\"*c\n\x0b\x46\x65\x61tureType\x12\x1b\n\x17\x46\x45\x41TURETYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nTRANSCRIPT\x10\x01\x12\x15\n\x11REGULATORYFEATURE\x10\x02\x12\x10\n\x0cMOTIFFEATURE\x10\x03*\xe1\x06\n\x07\x42ioType\x12\x17\n\x13\x42IOTYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14PROCESSED_TRANSCRIPT\x10\x01\x12\n\n\x06LNCRNA\x10\x02\x12\r\n\tANTISENSE\x10\x03\x12\x10\n\x0cMACRO_LNCRNA\x10\x04\x12\x0e\n\nNON_CODING\x10\x05\x12\x13\n\x0fRETAINED_INTRON\x10\x06\x12\x12\n\x0eSENSE_INTRONIC\x10\x07\x12\x15\n\x11SENSE_OVERLAPPING\x10\x08\x12\x0b\n\x07LINCRNA\x10\t\x12\t\n\x05NCRNA\x10\n\x12\t\n\x05MIRNA\x10\x0b\x12\x0b\n\x07MISCRNA\x10\x0c\x12\t\n\x05PIRNA\x10\r\x12\x08\n\x04RRNA\x10\x0e\x12\t\n\x05SIRNA\x10\x0f\x12\t\n\x05SNRNA\x10\x10\x12\n\n\x06SNORNA\x10\x11\x12\x08\n\x04TRNA\x10\x12\x12\x0c\n\x08VAULTRNA\x10\x13\x12\x12\n\x0ePROTEIN_CODING\x10\x14\x12\x0e\n\nPSEUDOGENE\x10\x15\x12\x11\n\rIG_PSEUDOGENE\x10\x16\x12\x1a\n\x16POLYMORPHIC_PSEUDOGENE\x10\x17\x12\x18\n\x14PROCESSED_PSEUDOGENE\x10\x18\x12\x1a\n\x16TRANSCRIBED_PSEUDOGENE\x10\x19\x12\x19\n\x15TRANSLATED_PSEUDOGENE\x10\x1a\x12\x16\n\x12UNITARY_PSEUDOGENE\x10\x1b\x12\x1a\n\x16UNPROCESSED_PSEUDOGENE\x10\x1c\x12\x0f\n\x0bREADTHROUGH\x10\x1d\x12\x1a\n\x16STOP_CODON_READTHROUGH\x10\x1e\x12\x07\n\x03TEC\x10\x1f\x12\x0b\n\x07TR_GENE\x10 \x12\r\n\tTR_C_GENE\x10!\x12\r\n\tTR_D_GENE\x10\"\x12\r\n\tTR_J_GENE\x10#\x12\r\n\tTR_V_GENE\x10$\x12\x0b\n\x07IG_GENE\x10%\x12\r\n\tIG_C_GENE\x10&\x12\r\n\tIG_D_GENE\x10\'\x12\r\n\tIG_J_GENE\x10(\x12\r\n\tIG_V_GENE\x10)\x12\x1b\n\x17NONSENSE_MEDIATED_DECAY\x10*\x12\x0c\n\x08PROMOTER\x10+\x12\x1c\n\x18PROMOTER_FLANKING_REGION\x10,\x12\x0c\n\x08\x45NHANCER\x10-\x12\x15\n\x11\x43TCF_BINDING_SITE\x10.\x12\x19\n\x15OPEN_CHROMATIN_REGION\x10/*\x8b\t\n\x0b\x43onsequence\x12\x1b\n\x17\x43ONSEQUENCE_UNSPECIFIED\x10\x00\x12\x17\n\x13TRANSCRIPT_ABLATION\x10\x01\x12\x1b\n\x17SPLICE_ACCEPTOR_VARIANT\x10\x02\x12\x18\n\x14SPLICE_DONOR_VARIANT\x10\x03\x12\x0f\n\x0bSTOP_GAINED\x10\x04\x12\x16\n\x12\x46RAMESHIFT_VARIANT\x10\x05\x12\r\n\tSTOP_LOST\x10\x06\x12\x0e\n\nSTART_LOST\x10\x07\x12\x1c\n\x18TRANSCRIPT_AMPLIFICATION\x10\x08\x12\x15\n\x11INFRAME_INSERTION\x10\t\x12\x14\n\x10INFRAME_DELETION\x10\n\x12\x14\n\x10MISSENSE_VARIANT\x10\x0b\x12\x1c\n\x18PROTEIN_ALTERING_VARIANT\x10\x0c\x12\x19\n\x15SPLICE_REGION_VARIANT\x10\r\x12%\n!INCOMPLETE_TERMINAL_CODON_VARIANT\x10\x0e\x12\x1a\n\x16START_RETAINED_VARIANT\x10\x0f\x12\x19\n\x15STOP_RETAINED_VARIANT\x10\x10\x12\x16\n\x12SYNONYMOUS_VARIANT\x10\x11\x12\x1b\n\x17\x43ODING_SEQUENCE_VARIANT\x10\x12\x12\x18\n\x14MATURE_MIRNA_VARIANT\x10\x13\x12\x1a\n\x16\x46IVE_PRIME_UTR_VARIANT\x10\x14\x12\x1b\n\x17THREE_PRIME_UTR_VARIANT\x10\x15\x12&\n\"NON_CODING_TRANSCRIPT_EXON_VARIANT\x10\x16\x12\x12\n\x0eINTRON_VARIANT\x10\x17\x12\x1a\n\x16NMD_TRANSCRIPT_VARIANT\x10\x18\x12!\n\x1dNON_CODING_TRANSCRIPT_VARIANT\x10\x19\x12\x19\n\x15UPSTREAM_GENE_VARIANT\x10\x1a\x12\x1b\n\x17\x44OWNSTREAM_GENE_VARIANT\x10\x1b\x12\x11\n\rTFBS_ABLATION\x10\x1c\x12\x16\n\x12TFBS_AMPLIFICATION\x10\x1d\x12\x1b\n\x17TF_BINDING_SITE_VARIANT\x10\x1e\x12\x1e\n\x1aREGULATORY_REGION_ABLATION\x10\x1f\x12#\n\x1fREGULATORY_REGION_AMPLIFICATION\x10 \x12\x16\n\x12\x46\x45\x41TURE_ELONGATION\x10!\x12\x1d\n\x19REGULATORY_REGION_VARIANT\x10\"\x12\x16\n\x12\x46\x45\x41TURE_TRUNCATION\x10#\x12\x16\n\x12INTERGENIC_VARIANT\x10$\x12\'\n#SPLICE_POLYPYRIMIDINE_TRACT_VARIANT\x10%\x12!\n\x1dSPLICE_DONOR_5TH_BASE_VARIANT\x10&\x12\x1f\n\x1bSPLICE_DONOR_REGION_VARIANT\x10\'\x12\x1d\n\x19\x43ODING_TRANSCRIPT_VARIANT\x10(\x12\x14\n\x10SEQUENCE_VARIANT\x10)*O\n\x06Impact\x12\x16\n\x12IMPACT_UNSPECIFIED\x10\x00\x12\x08\n\x04HIGH\x10\x01\x12\x0c\n\x08MODERATE\x10\x02\x12\x07\n\x03LOW\x10\x03\x12\x0c\n\x08MODIFIER\x10\x04*<\n\x04SIFT\x12\x14\n\x10SIFT_UNSPECIFIED\x10\x00\x12\r\n\tTOLERATED\x10\x01\x12\x0f\n\x0b\x44\x45LETERIOUS\x10\x02*k\n\x08PolyPhen\x12\x18\n\x14POLYPHEN_UNSPECIFIED\x10\x00\x12\n\n\x06\x42\x45NIGN\x10\x01\x12\x15\n\x11POSSIBLY_DAMAGING\x10\x02\x12\x15\n\x11PROBABLY_DAMAGING\x10\x03\x12\x0b\n\x07UNKNOWN\x10\x04*\xd1\x03\n\x10\x43linSignificance\x12\x16\n\x12\x43LNSIG_UNSPECIFIED\x10\x00\x12\x11\n\rCLNSIG_BENIGN\x10\x01\x12\x11\n\rLIKELY_BENIGN\x10\x02\x12\x1a\n\x16UNCERTAIN_SIGNIFICANCE\x10\x03\x12\x15\n\x11LIKELY_PATHOGENIC\x10\x04\x12\x0e\n\nPATHOGENIC\x10\x05\x12\x11\n\rDRUG_RESPONSE\x10\x06\x12\x0f\n\x0b\x41SSOCIATION\x10\x07\x12\x0f\n\x0bRISK_FACTOR\x10\x08\x12\x0e\n\nPROTECTIVE\x10\t\x12\x0b\n\x07\x41\x46\x46\x45\x43TS\x10\n\x12\x17\n\x13\x43ONFERS_SENSITIVITY\x10\x0b\x12\x1f\n\x1b\x43ONFLICTING_INTERPRETATIONS\x10\x0c\x12\x10\n\x0cNOT_PROVIDED\x10\r\x12\t\n\x05OTHER\x10\x0e\x12$\n LIKELY_PATHOGENIC_LOW_PENETRANCE\x10\x0f\x12\x1d\n\x19PATHOGENIC_LOW_PENETRANCE\x10\x10\x12\x19\n\x15UNCERTAIN_RISK_ALLELE\x10\x11\x12\x16\n\x12LIKELY_RISK_ALLELE\x10\x12\x12\x1b\n\x17\x45STABLISHED_RISK_ALLELE\x10\x13*e\n\rAlphaMissense\x12\x12\n\x0e\x41M_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41M_LIKELY_BENIGN\x10\x01\x12\x18\n\x14\x41M_LIKELY_PATHOGENIC\x10\x02\x12\x10\n\x0c\x41M_AMBIGUOUS\x10\x03*\x85\x01\n\rKinshipDegree\x12\x17\n\x13KINSHIP_UNSPECIFIED\x10\x00\x12\x15\n\x11TWINS_MONOZYGOTIC\x10\x01\x12\x10\n\x0c\x46IRST_DEGREE\x10\x02\x12\x11\n\rSECOND_DEGREE\x10\x03\x12\x10\n\x0cTHIRD_DEGREE\x10\x04\x12\r\n\tUNRELATED\x10\x05\x32\xbb#\n\x0e\x44naerysService\x12]\n\x06Health\x12\'.org.dnaerys.cluster.grpc.HealthRequest\x1a(.org.dnaerys.cluster.grpc.HealthResponse\"\x00\x12o\n\x0c\x43lusterNodes\x12-.org.dnaerys.cluster.grpc.ClusterNodesRequest\x1a..org.dnaerys.cluster.grpc.ClusterNodesResponse\"\x00\x12l\n\x0b\x44\x61tasetInfo\x12,.org.dnaerys.cluster.grpc.DatasetInfoRequest\x1a-.org.dnaerys.cluster.grpc.DatasetInfoResponse\"\x00\x12y\n\x16SelectVariantsInRegion\x12\x30.org.dnaerys.cluster.grpc.AllelesInRegionRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x80\x01\n\x15\x43ountVariantsInRegion\x12\x35.org.dnaerys.cluster.grpc.CountAllelesInRegionRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\x8b\x01\n\x1fSelectVariantsInRegionInSamples\x12\x39.org.dnaerys.cluster.grpc.AllelesInRegionInSamplesRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x92\x01\n\x1e\x43ountVariantsInRegionInSamples\x12>.org.dnaerys.cluster.grpc.CountAllelesInRegionInSamplesRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\x9d\x01\n(SelectVariantsInRegionInSamplesWithStats\x12\x39.org.dnaerys.cluster.grpc.AllelesInRegionInSamplesRequest\x1a\x32.org.dnaerys.cluster.grpc.AllelesWithStatsResponse\"\x00\x30\x01\x12{\n\x17SelectVariantsInBracket\x12\x31.org.dnaerys.cluster.grpc.AllelesInBracketRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x82\x01\n\x16\x43ountVariantsInBracket\x12\x36.org.dnaerys.cluster.grpc.CountAllelesInBracketRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\x8d\x01\n SelectVariantsInBracketInSamples\x12:.org.dnaerys.cluster.grpc.AllelesInBracketInSamplesRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x94\x01\n\x1f\x43ountVariantsInBracketInSamples\x12?.org.dnaerys.cluster.grpc.CountAllelesInBracketInSamplesRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\x85\x01\n\x1cSelectVariantsInMultiRegions\x12\x36.org.dnaerys.cluster.grpc.AllelesInMultiRegionsRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x8c\x01\n\x1b\x43ountVariantsInMultiRegions\x12;.org.dnaerys.cluster.grpc.CountAllelesInMultiRegionsRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\x97\x01\n%SelectVariantsInMultiRegionsWithStats\x12\x36.org.dnaerys.cluster.grpc.AllelesInMultiRegionsRequest\x1a\x32.org.dnaerys.cluster.grpc.AllelesWithStatsResponse\"\x00\x30\x01\x12\x97\x01\n%SelectVariantsInMultiRegionsInSamples\x12?.org.dnaerys.cluster.grpc.AllelesInMultiRegionsInSamplesRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12\x9e\x01\n$CountVariantsInMultiRegionsInSamples\x12\x44.org.dnaerys.cluster.grpc.CountAllelesInMultiRegionsInSamplesRequest\x1a..org.dnaerys.cluster.grpc.CountAllelesResponse\"\x00\x12\xa9\x01\n.SelectVariantsInMultiRegionsInSamplesWithStats\x12?.org.dnaerys.cluster.grpc.AllelesInMultiRegionsInSamplesRequest\x1a\x32.org.dnaerys.cluster.grpc.AllelesWithStatsResponse\"\x00\x30\x01\x12i\n\x07TopNHWE\x12(.org.dnaerys.cluster.grpc.TopNHWERequest\x1a\x32.org.dnaerys.cluster.grpc.AllelesWithStatsResponse\"\x00\x12k\n\x08TopNchi2\x12).org.dnaerys.cluster.grpc.TopNchi2Request\x1a\x32.org.dnaerys.cluster.grpc.AllelesWithStatsResponse\"\x00\x12v\n\x15SelectSamplesInRegion\x12\x30.org.dnaerys.cluster.grpc.SamplesInRegionRequest\x1a).org.dnaerys.cluster.grpc.SamplesResponse\"\x00\x12z\n\x14\x43ountSamplesInRegion\x12\x30.org.dnaerys.cluster.grpc.SamplesInRegionRequest\x1a..org.dnaerys.cluster.grpc.CountSamplesResponse\"\x00\x12\x82\x01\n\x1bSelectSamplesInMultiRegions\x12\x36.org.dnaerys.cluster.grpc.SamplesInMultiRegionsRequest\x1a).org.dnaerys.cluster.grpc.SamplesResponse\"\x00\x12\x86\x01\n\x1a\x43ountSamplesInMultiRegions\x12\x36.org.dnaerys.cluster.grpc.SamplesInMultiRegionsRequest\x1a..org.dnaerys.cluster.grpc.CountSamplesResponse\"\x00\x12x\n\x19SelectSamplesHomReference\x12..org.dnaerys.cluster.grpc.SamplesHomRefRequest\x1a).org.dnaerys.cluster.grpc.SamplesResponse\"\x00\x12|\n\x18\x43ountSamplesHomReference\x12..org.dnaerys.cluster.grpc.SamplesHomRefRequest\x1a..org.dnaerys.cluster.grpc.CountSamplesResponse\"\x00\x12\x66\n\x0cSelectDeNovo\x12\'.org.dnaerys.cluster.grpc.DeNovoRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12p\n\x11SelectHetDominant\x12,.org.dnaerys.cluster.grpc.HetDominantRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12r\n\x12SelectHomRecessive\x12-.org.dnaerys.cluster.grpc.HomRecessiveRequest\x1a).org.dnaerys.cluster.grpc.AllelesResponse\"\x00\x30\x01\x12T\n\x03Prs\x12$.org.dnaerys.cluster.grpc.PRSRequest\x1a%.org.dnaerys.cluster.grpc.PRSResponse\"\x00\x12l\n\x10SexMismatchCheck\x12\'.org.dnaerys.cluster.grpc.FstatXRequest\x1a-.org.dnaerys.cluster.grpc.SexMismatchResponse\"\x00\x12]\n\x06\x46statX\x12\'.org.dnaerys.cluster.grpc.FstatXRequest\x1a(.org.dnaerys.cluster.grpc.FstatXResponse\"\x00\x12`\n\x07Kinship\x12(.org.dnaerys.cluster.grpc.KinshipRequest\x1a).org.dnaerys.cluster.grpc.KinshipResponse\"\x00\x12\x66\n\nKinshipDuo\x12+.org.dnaerys.cluster.grpc.KinshipDuoRequest\x1a).org.dnaerys.cluster.grpc.KinshipResponse\"\x00\x12h\n\x0bKinshipTrio\x12,.org.dnaerys.cluster.grpc.KinshipTrioRequest\x1a).org.dnaerys.cluster.grpc.KinshipResponse\"\x00\x12r\n\rSampleKinship\x12..org.dnaerys.cluster.grpc.SampleKinshipRequest\x1a/.org.dnaerys.cluster.grpc.SampleKinshipResponse\"\x00\x42\x10\x42\x0c\x44naerysProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dnaerys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\014DnaerysProtoP\001'
  _globals['_REFASSEMBLY']._serialized_start=12164
  _globals['_REFASSEMBLY']._serialized_end=12227
  _globals['_CHROMOSOME']._serialized_start=12230
  _globals['_CHROMOSOME']._serialized_end=12559
  _globals['_VARIANTTYPE']._serialized_start=12562
  _globals['_VARIANTTYPE']._serialized_end=13397
  _globals['_FEATURETYPE']._serialized_start=13399
  _globals['_FEATURETYPE']._serialized_end=13498
  _globals['_BIOTYPE']._serialized_start=13501
  _globals['_BIOTYPE']._serialized_end=14366
  _globals['_CONSEQUENCE']._serialized_start=14369
  _globals['_CONSEQUENCE']._serialized_end=15532
  _globals['_IMPACT']._serialized_start=15534
  _globals['_IMPACT']._serialized_end=15613
  _globals['_SIFT']._serialized_start=15615
  _globals['_SIFT']._serialized_end=15675
  _globals['_POLYPHEN']._serialized_start=15677
  _globals['_POLYPHEN']._serialized_end=15784
  _globals['_CLINSIGNIFICANCE']._serialized_start=15787
  _globals['_CLINSIGNIFICANCE']._serialized_end=16252
  _globals['_ALPHAMISSENSE']._serialized_start=16254
  _globals['_ALPHAMISSENSE']._serialized_end=16355
  _globals['_KINSHIPDEGREE']._serialized_start=16358
  _globals['_KINSHIPDEGREE']._serialized_end=16491
  _globals['_HEALTHREQUEST']._serialized_start=43
  _globals['_HEALTHREQUEST']._serialized_end=58
  _globals['_HEALTHRESPONSE']._serialized_start=60
  _globals['_HEALTHRESPONSE']._serialized_end=92
  _globals['_CLUSTERNODESREQUEST']._serialized_start=94
  _globals['_CLUSTERNODESREQUEST']._serialized_end=115
  _globals['_CLUSTERNODESRESPONSE']._serialized_start=117
  _globals['_CLUSTERNODESRESPONSE']._serialized_end=226
  _globals['_DATASETINFOREQUEST']._serialized_start=228
  _globals['_DATASETINFOREQUEST']._serialized_end=278
  _globals['_DATASETINFORESPONSE']._serialized_start=281
  _globals['_DATASETINFORESPONSE']._serialized_end=671
  _globals['_COHORT']._serialized_start=674
  _globals['_COHORT']._serialized_end=845
  _globals['_PRS']._serialized_start=847
  _globals['_PRS']._serialized_end=901
  _globals['_ANNOTATIONS']._serialized_start=904
  _globals['_ANNOTATIONS']._serialized_end=1795
  _globals['_ALLELESINREGIONREQUEST']._serialized_start=1798
  _globals['_ALLELESINREGIONREQUEST']._serialized_end=2143
  _globals['_ALLELESINBRACKETREQUEST']._serialized_start=2146
  _globals['_ALLELESINBRACKETREQUEST']._serialized_end=2536
  _globals['_ALLELESINBRACKETINSAMPLESREQUEST']._serialized_start=2539
  _globals['_ALLELESINBRACKETINSAMPLESREQUEST']._serialized_end=2955
  _globals['_ALLELESINREGIONINSAMPLESREQUEST']._serialized_start=2958
  _globals['_ALLELESINREGIONINSAMPLESREQUEST']._serialized_end=3329
  _globals['_ALLELESINMULTIREGIONSREQUEST']._serialized_start=3332
  _globals['_ALLELESINMULTIREGIONSREQUEST']._serialized_end=3683
  _globals['_ALLELESINMULTIREGIONSINSAMPLESREQUEST']._serialized_start=3686
  _globals['_ALLELESINMULTIREGIONSINSAMPLESREQUEST']._serialized_end=4063
  _globals['_ALLELESRESPONSE']._serialized_start=4066
  _globals['_ALLELESRESPONSE']._serialized_end=4242
  _globals['_VARIANT']._serialized_start=4245
  _globals['_VARIANT']._serialized_end=4612
  _globals['_ALLELESWITHSTATSRESPONSE']._serialized_start=4615
  _globals['_ALLELESWITHSTATSRESPONSE']._serialized_end=4809
  _globals['_VARIANTWITHSTATS']._serialized_start=4812
  _globals['_VARIANTWITHSTATS']._serialized_end=5037
  _globals['_TOPNCHI2REQUEST']._serialized_start=5039
  _globals['_TOPNCHI2REQUEST']._serialized_end=5097
  _globals['_TOPNHWEREQUEST']._serialized_start=5099
  _globals['_TOPNHWEREQUEST']._serialized_end=5139
  _globals['_SAMPLESINREGIONREQUEST']._serialized_start=5142
  _globals['_SAMPLESINREGIONREQUEST']._serialized_end=5487
  _globals['_SAMPLESINMULTIREGIONSREQUEST']._serialized_start=5490
  _globals['_SAMPLESINMULTIREGIONSREQUEST']._serialized_end=5841
  _globals['_SAMPLESHOMREFREQUEST']._serialized_start=5844
  _globals['_SAMPLESHOMREFREQUEST']._serialized_end=6021
  _globals['_SAMPLESRESPONSE']._serialized_start=6024
  _globals['_SAMPLESRESPONSE']._serialized_end=6164
  _globals['_DENOVOREQUEST']._serialized_start=6167
  _globals['_DENOVOREQUEST']._serialized_end=6528
  _globals['_HETDOMINANTREQUEST']._serialized_start=6531
  _globals['_HETDOMINANTREQUEST']._serialized_end=6922
  _globals['_HOMRECESSIVEREQUEST']._serialized_start=6925
  _globals['_HOMRECESSIVEREQUEST']._serialized_end=7321
  _globals['_PRSREQUEST']._serialized_start=7323
  _globals['_PRSREQUEST']._serialized_end=7428
  _globals['_PRSRESPONSE']._serialized_start=7431
  _globals['_PRSRESPONSE']._serialized_end=7674
  _globals['_SAMPLESCORE']._serialized_start=7677
  _globals['_SAMPLESCORE']._serialized_end=7825
  _globals['_FSTATXREQUEST']._serialized_start=7828
  _globals['_FSTATXREQUEST']._serialized_end=7988
  _globals['_SEXMISMATCHRESPONSE']._serialized_start=7991
  _globals['_SEXMISMATCHRESPONSE']._serialized_end=8226
  _globals['_SAMPLESTAT']._serialized_start=8228
  _globals['_SAMPLESTAT']._serialized_end=8316
  _globals['_FSTATXRESPONSE']._serialized_start=8319
  _globals['_FSTATXRESPONSE']._serialized_end=8531
  _globals['_KINSHIPREQUEST']._serialized_start=8534
  _globals['_KINSHIPREQUEST']._serialized_end=8677
  _globals['_KINSHIPDUOREQUEST']._serialized_start=8679
  _globals['_KINSHIPDUOREQUEST']._serialized_end=8745
  _globals['_KINSHIPTRIOREQUEST']._serialized_start=8748
  _globals['_KINSHIPTRIOREQUEST']._serialized_end=8908
  _globals['_KINSHIPRESPONSE']._serialized_start=8911
  _globals['_KINSHIPRESPONSE']._serialized_end=9068
  _globals['_RELATEDNESS']._serialized_start=9070
  _globals['_RELATEDNESS']._serialized_end=9191
  _globals['_SAMPLEKINSHIPREQUEST']._serialized_start=9194
  _globals['_SAMPLEKINSHIPREQUEST']._serialized_end=9346
  _globals['_SAMPLEKINSHIPRESPONSE']._serialized_start=9349
  _globals['_SAMPLEKINSHIPRESPONSE']._serialized_end=9544
  _globals['_RELATEDNESSPERSAMPLE']._serialized_start=9547
  _globals['_RELATEDNESSPERSAMPLE']._serialized_end=9746
  _globals['_COUNTALLELESINREGIONREQUEST']._serialized_start=9749
  _globals['_COUNTALLELESINREGIONREQUEST']._serialized_end=10070
  _globals['_COUNTALLELESINREGIONINSAMPLESREQUEST']._serialized_start=10073
  _globals['_COUNTALLELESINREGIONINSAMPLESREQUEST']._serialized_end=10420
  _globals['_COUNTALLELESINBRACKETREQUEST']._serialized_start=10423
  _globals['_COUNTALLELESINBRACKETREQUEST']._serialized_end=10789
  _globals['_COUNTALLELESINBRACKETINSAMPLESREQUEST']._serialized_start=10792
  _globals['_COUNTALLELESINBRACKETINSAMPLESREQUEST']._serialized_end=11184
  _globals['_COUNTALLELESINMULTIREGIONSREQUEST']._serialized_start=11187
  _globals['_COUNTALLELESINMULTIREGIONSREQUEST']._serialized_end=11514
  _globals['_COUNTALLELESINMULTIREGIONSINSAMPLESREQUEST']._serialized_start=11517
  _globals['_COUNTALLELESINMULTIREGIONSINSAMPLESREQUEST']._serialized_end=11870
  _globals['_COUNTALLELESRESPONSE']._serialized_start=11873
  _globals['_COUNTALLELESRESPONSE']._serialized_end=12016
  _globals['_COUNTSAMPLESRESPONSE']._serialized_start=12019
  _globals['_COUNTSAMPLESRESPONSE']._serialized_end=12162
  _globals['_DNAERYSSERVICE']._serialized_start=16494
  _globals['_DNAERYSSERVICE']._serialized_end=21033
# @@protoc_insertion_point(module_scope)
